import React, {Component} from 'react';
import {DayPilot, DayPilotScheduler} from "daypilot-pro-react";

class Scheduler extends Component {

  constructor(props) {
    super(props);

    this.state = {
      zoom: 0,
      zoomPosition: "middle",
      zoomLevels: [
        {
          name: "Days",
          properties: {
            scale: "Day",
            cellWidth: 40,
            timeHeaders: [{groupBy: "Year"}, {groupBy: "Month", format: "MMMM"}, {groupBy: "Day", format: "d"}],
            startDate: args => args.date.firstDayOfYear(),
            days: args => args.date.daysInYear(),
          }
        },
        {
          name: "Half-Days",
          properties: {
            scale: "CellDuration",
            cellDuration: 720,
            cellWidth: 40,
            timeHeaders: [{groupBy: "Month"}, {groupBy: "Day", format: "ddd d"}, {groupBy: "Cell", format: "tt"}],
            startDate: args => args.date.firstDayOfMonth(),
            days: args => args.date.daysInMonth(),
          }
        },
        {
          name: "Hours",
          properties: {
            scale: "Hour",
            cellWidth: 40,
            timeHeaders: [{groupBy: "Month"}, {groupBy: "Day", format: "dddd d"}, {groupBy: "Hour"}],
            startDate: args => args.date.firstDayOfWeek(),
            days: args => 7,
          }
        },
        {
          name: "15-Minute Cells",
          properties: {
            scale: "CellDuration",
            cellDuration: 15,
            cellWidth: 40,
            timeHeaders: [{groupBy: "Day", format: "dddd MMMM d, yyyy"}, {groupBy: "Hour"}, {groupBy: "Cell"}],
            startDate: args => args.date.getDatePart(),
            days: args => 1,
          }
        },
      ],
      useEventBoxes: "Never",
      timeRangeSelectedHandling: "Enabled",
      onTimeRangeSelected: async (args) => {
        const dp = args.control;
        const modal = await DayPilot.Modal.prompt("Create a new event:", "Event 1");
        dp.clearSelection();
        if (modal.canceled) { return; }
        dp.events.add({
          start: args.start,
          end: args.end,
          id: DayPilot.guid(),
          resource: args.resource,
          text: modal.result
        });
      },
      treeEnabled: true,
    };
  }

  componentDidMount() {

    // load resource and event data
    this.setState({
      resources: [
        {name: "Resource A", id: "A"},
        {name: "Resource B", id: "B"},
        {name: "Resource C", id: "C"},
        {name: "Resource D", id: "D"},
        {name: "Resource E", id: "E"},
        {name: "Resource F", id: "F"},
        {name: "Resource G", id: "G"}
      ],
      events: [
        {
          id: 1,
          text: "Event 1",
          start: "2021-08-02T00:00:00",
          end: "2021-08-05T00:00:00",
          resource: "A"
        },
        {
          id: 2,
          text: "Event 2",
          start: "2021-08-03T00:00:00",
          end: "2021-08-10T00:00:00",
          resource: "C",
          barColor: "#38761d",
          barBackColor: "#93c47d"
        },
        {
          id: 3,
          text: "Event 3",
          start: "2021-08-02T00:00:00",
          end: "2021-08-08T00:00:00",
          resource: "D",
          barColor: "#f1c232",
          barBackColor: "#f1c232"
        },
        {
          id: 4,
          text: "Event 3",
          start: "2021-08-02T00:00:00",
          end: "2021-08-08T00:00:00",
          resource: "E",
          barColor: "#cc0000",
          barBackColor: "#ea9999"
        }
      ]
    });

    this.scheduler.scrollTo("2021-08-01");

  }

  changeZoomLevel() {
    const value = parseInt(this.zoom.value, 10);
    this.setState({
      zoom: value
    });
    // this.scheduler.zoom.setActive(value);
    // console.log("zoom set to ", value);
  }

  timelineZoomOut() {
    const current = this.state.zoom;
    const zoom = Math.max(0, current - 1);
    this.setState({
      zoom
    });
  }

  timelineZoomIn() {
    const current = this.state.zoom;
    const max = this.state.zoomLevels.length - 1;
    const zoom = Math.min(max, current + 1);
    this.setState({
      zoom
    });
  }

  render() {
    var {...config} = this.state;
    return (
      <div>
        <div className={"space"}>
          <button id="zoom-out" onClick={ev => this.timelineZoomOut()}>
            <svg style={{width: "16px", height: "16px"}}><use href={"icons/daypilot.svg#minus-2"} /></svg>
          </button>

          <input type="range" min="0" max="3" step="1" id="zoom-level" value={this.state.zoom} onChange={ev => this.changeZoomLevel()} ref={el => this.zoom = el} />

          <button id="zoom-in" onClick={ev => this.timelineZoomIn()}>
            <svg style={{width: "16px", height: "16px"}}><use href={"icons/daypilot.svg#plus-2"} /></svg>
          </button>

          <span id="label">Zoom level: {this.state.zoomLevels[this.state.zoom].name}</span>
        </div>
        <DayPilotScheduler
          {...config}
          ref={component => {
            this.scheduler = component && component.control;
          }}
        />
      </div>
    );
  }
}

export default Scheduler;
